@@ -3,16 +3,16 @@
 
 #define GHC_STAGE (1 + 1)
 
-#define BuildPlatform_TYPE  i386_unknown_openbsd
-#define HostPlatform_TYPE   i386_unknown_openbsd
+#define BuildPlatform_TYPE  x86_64_unknown_openbsd
+#define HostPlatform_TYPE   x86_64_unknown_openbsd
 
-#define i386_unknown_openbsd_BUILD  1
-#define i386_unknown_openbsd_HOST  1
+#define x86_64_unknown_openbsd_BUILD  1
+#define x86_64_unknown_openbsd_HOST  1
 
-#define i386_BUILD_ARCH  1
-#define i386_HOST_ARCH  1
-#define BUILD_ARCH  "i386"
-#define HOST_ARCH  "i386"
+#define x86_64_BUILD_ARCH  1
+#define x86_64_HOST_ARCH  1
+#define BUILD_ARCH  "x86_64"
+#define HOST_ARCH  "x86_64"
 
 #define openbsd_BUILD_OS  1
 #define openbsd_HOST_OS  1
